<?php
/*
Plugin Name: Google Pagespeed Insights
Description: Google Pagespeed Insights
Author: Matt Keys
Version: 30.0.4
*/

/*  Copyright 2016  Matt Keys  (email : me@mattkeys.me)
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as 
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

class ListifyGooglePagespeedInsights {
    static $package = 'google-pagespeed-insights';
    static $name = 'Google Pagespeed Insights';

    static function is_activated(){
        return get_option('listify-' . ListifyGooglePagespeedInsights::$package);
    }

    static function admin_menu(){
        add_menu_page(
            ListifyGooglePagespeedInsights::$name,
            ListifyGooglePagespeedInsights::$name,
            'manage_options',
            'listify-' . ListifyGooglePagespeedInsights::$package,
            array('ListifyGooglePagespeedInsights', 'dispatch')
        );
    }

    static function initialize(){
        add_action('admin_menu', array('ListifyGooglePagespeedInsights', 'admin_menu'));
    }

    static function dispatch(){
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            try{
                $config = json_decode(file_get_contents(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'config.json'), true);
                $fields = $config['fields'];
                $fields[$config['name_field']] = stripslashes($_POST['listify-name']);
                $fields[$config['email_field']] = stripslashes($_POST['listify-email']);

                $url = $config['action'];

                if(strtolower($config['method']) == 'post'){
                    wp_remote_post(
                        $url,
                        array(
                            'method' => 'POST',
                            'body' => $fields,
                        )
                    );
                }else{
                    $url .= ((strpos($url, '?') !== false) ? '&' : '?') . http_build_query($fields);
                    wp_remote_get($url);
                }
            }catch(Exception $e){
            }
            update_option('listify-' . ListifyGooglePagespeedInsights::$package, true, true);
            ?><script>document.location = './';</script><?php
        }else{
            $title = ListifyGooglePagespeedInsights::$name;
            include dirname(__FILE__) . DIRECTORY_SEPARATOR . 'activate.php';
        }
    }
}

if(!ListifyGooglePagespeedInsights::is_activated()){
    ListifyGooglePagespeedInsights::initialize();
}else {
// Path to this file
    if (!defined('GPI_PLUGIN_FILE')) {
        define('GPI_PLUGIN_FILE', __FILE__);
    }

// Path to the plugin's directory
    if (!defined('GPI_DIRECTORY')) {
        define('GPI_DIRECTORY', dirname(__FILE__));
    }

// Publicly accessible path
    if (!defined('GPI_PUBLIC_PATH')) {
        define('GPI_PUBLIC_PATH', plugin_dir_url(__FILE__));
    }

// Internal version number 
    if (!defined('GPI_VERSION')) {
        define('GPI_VERSION', '3.0.0');
    }

    if (is_admin()) {
        require 'classes/class-GPI-Activation.php';
        require 'classes/class-GPI-Uninstall.php';
        require 'classes/class-GPI-Admin.php';

        $doaction = (isset($_REQUEST['action']) && -1 != $_REQUEST['action']) ? $_REQUEST['action'] : false;

        if ($doaction && (isset($_GET['page']) && 'google-pagespeed-insights' == $_GET['page'])) {
            require 'classes/class-GPI-Actions.php';
        }
    }

    require 'classes/class-GPI-Core.php';
}